@@ -20,6 +20,7 @@ from LivestockCV.core.crop import crop
 from LivestockCV.core.invert import invert
 from LivestockCV.core import roi
 from LivestockCV.core import thresholding
+from LivestockCV.core import gaussian_blur
 # add new functions to end of lists
 
 # Auto versioning
@@ -27,4 +28,4 @@ from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
 
-__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'roi', 'threshold']
+__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'roi', 'thresholding', 'gaussian_blur']
