@@ -2,9 +2,9 @@
 
 import cv2
 import os
-from LivestockCV import print_image
-from LivestockCV import plot_image
-from LivestockCV import params
+from LivestockCV.core import print_image
+from LivestockCV.core import plot_image
+from LivestockCV.core import params
 
 
 def invert(gray_img):
